---
layout: article
title: Find your Accounts
mode: immersive
header:
  theme: dark
article_header:
  type: cover
  image:
    src: /assets/img/FindMyAccounts.png
---

## Usage
Use the Open source edition or get immediate free access to the online edition. <br />
[Download](https://github.com/H3nkl3r/FindMyAccounts){:.button.button--primary.button--pill} or [Online Tool](https://app.findmyaccounts.com){:.button.button--primary.button--pill}

*currently not working for gmail*

## But why?
So why is it important to keep an eye on your online accounts? <br />

Well, for one thing, accounts mean all kinds of data, some of which is sensitive - you don't want it falling into the wrong hands!